@@ -41,6 +41,7 @@ index((archive_set_header_property), 2, archive, archive).
 index((archive_extract), 3, archive, archive).
 index((archive_entries), 2, archive, archive).
 index((archive_data_stream), 3, archive, archive).
+index((archive_foldl), 4, archive, archive).
 index((arithmetic_function), 1, arithmetic, arithmetic).
 index((arithmetic_expression_value), 2, arithmetic, arithmetic).
 index((empty_assoc), 1, assoc, assoc).
@@ -312,6 +313,22 @@ index((reconsult), 1, edinburgh, edinburgh).
 index((debug), 0, edinburgh, edinburgh).
 index((nodebug), 0, edinburgh, edinburgh).
 index((fileerrors), 2, edinburgh, edinburgh).
+index((el_wrap), 0, editline, editline).
+index((el_wrap), 4, editline, editline).
+index((el_wrapped), 1, editline, editline).
+index((el_unwrap), 1, editline, editline).
+index((el_source), 2, editline, editline).
+index((el_bind), 2, editline, editline).
+index((el_addfn), 4, editline, editline).
+index((el_cursor), 2, editline, editline).
+index((el_line), 2, editline, editline).
+index((el_insertstr), 2, editline, editline).
+index((el_deletestr), 2, editline, editline).
+index((el_history), 2, editline, editline).
+index((el_history_events), 2, editline, editline).
+index((el_add_history), 2, editline, editline).
+index((el_write_history), 2, editline, editline).
+index((el_read_history), 2, editline, editline).
 index((edit), 1, prolog_edit, edit).
 index((edit), 0, prolog_edit, edit).
 index((type_error), 2, error, error).
@@ -391,6 +408,54 @@ index((iso_639_2), 2, iso_639, iso_639).
 index((iso_639_3), 2, iso_639, iso_639).
 index((iso_639), 2, iso_639, iso_639).
 index((isub), 4, isub, isub).
+index((jpl_get_default_jvm_opts), 1, jpl, jpl).
+index((jpl_set_default_jvm_opts), 1, jpl, jpl).
+index((jpl_get_actual_jvm_opts), 1, jpl, jpl).
+index((jpl_pl_lib_version), 1, jpl, jpl).
+index((jpl_c_lib_version), 1, jpl, jpl).
+index((jpl_pl_syntax), 1, jpl, jpl).
+index((jpl_new), 3, jpl, jpl).
+index((jpl_call), 4, jpl, jpl).
+index((jpl_get), 3, jpl, jpl).
+index((jpl_set), 3, jpl, jpl).
+index((jpl_servlet_byref), 3, jpl, jpl).
+index((jpl_servlet_byval), 3, jpl, jpl).
+index((jpl_class_to_classname), 2, jpl, jpl).
+index((jpl_class_to_type), 2, jpl, jpl).
+index((jpl_classname_to_class), 2, jpl, jpl).
+index((jpl_classname_to_type), 2, jpl, jpl).
+index((jpl_datum_to_type), 2, jpl, jpl).
+index((jpl_false), 1, jpl, jpl).
+index((jpl_is_class), 1, jpl, jpl).
+index((jpl_is_false), 1, jpl, jpl).
+index((jpl_is_null), 1, jpl, jpl).
+index((jpl_is_object), 1, jpl, jpl).
+index((jpl_is_object_type), 1, jpl, jpl).
+index((jpl_is_ref), 1, jpl, jpl).
+index((jpl_is_true), 1, jpl, jpl).
+index((jpl_is_type), 1, jpl, jpl).
+index((jpl_is_void), 1, jpl, jpl).
+index((jpl_null), 1, jpl, jpl).
+index((jpl_object_to_class), 2, jpl, jpl).
+index((jpl_object_to_type), 2, jpl, jpl).
+index((jpl_primitive_type), 1, jpl, jpl).
+index((jpl_ref_to_type), 2, jpl, jpl).
+index((jpl_true), 1, jpl, jpl).
+index((jpl_type_to_class), 2, jpl, jpl).
+index((jpl_type_to_classname), 2, jpl, jpl).
+index((jpl_void), 1, jpl, jpl).
+index((jpl_array_to_length), 2, jpl, jpl).
+index((jpl_array_to_list), 2, jpl, jpl).
+index((jpl_datums_to_array), 2, jpl, jpl).
+index((jpl_enumeration_element), 2, jpl, jpl).
+index((jpl_enumeration_to_list), 2, jpl, jpl).
+index((jpl_hashtable_pair), 2, jpl, jpl).
+index((jpl_iterator_element), 2, jpl, jpl).
+index((jpl_list_to_array), 2, jpl, jpl).
+index((jpl_terms_to_array), 2, jpl, jpl).
+index((jpl_array_to_terms), 2, jpl, jpl).
+index((jpl_map_element), 2, jpl, jpl).
+index((jpl_set_element), 2, jpl, jpl).
 index((lazy_list), 2, lazy_lists, lazy_lists).
 index((lazy_list), 3, lazy_lists, lazy_lists).
 index((lazy_list_materialize), 1, lazy_lists, lazy_lists).
@@ -571,6 +636,9 @@ index((paxos_set), 3, paxos, paxos).
 index((paxos_on_change), 2, paxos, paxos).
 index((paxos_on_change), 3, paxos, paxos).
 index((paxos_initialize), 1, paxos, paxos).
+index((paxos_admin_key), 2, paxos, paxos).
+index((paxos_property), 1, paxos, paxos).
+index((paxos_quorum_ask), 4, paxos, paxos).
 index((paxos_replicate_key), 3, paxos, paxos).
 index((re_match), 2, pcre, pcre).
 index((re_match), 3, pcre, pcre).
@@ -672,6 +740,7 @@ index((prolog_colourise_query), 3, prolog_colour, prolog_colour).
 index((syntax_colour), 2, prolog_colour, prolog_colour).
 index((syntax_message), 3, prolog_colour, prolog_colour).
 index((prolog_dump_runtime_variables), 0, prolog_config, prolog_config).
+index((apple_bundle_libdir), 1, prolog_config, prolog_config).
 index((format_spec), 2, prolog_format, prolog_format).
 index((format_spec), 3, prolog_format, prolog_format).
 index((format_types), 2, prolog_format, prolog_format).
@@ -1240,6 +1309,9 @@ index((/), 9, yall, yall).
 index((lambda_calls), 2, yall, yall).
 index((lambda_calls), 3, yall, yall).
 index((is_lambda), 1, yall, yall).
+index((yaml_read), 2, yaml, yaml).
+index((yaml_write), 2, yaml, yaml).
+index((yaml_write), 3, yaml, yaml).
 index((zip_open), 4, zip, zip).
 index((zip_close), 1, zip, zip).
 index((zip_close), 2, zip, zip).
